"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createtransferoptions as components_createtransferoptions,
    transferoptions as components_transferoptions,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateTransferOptionsRequestTypedDict(TypedDict):
    account_id: str
    r"""The partner's Moov account ID."""
    create_transfer_options: (
        components_createtransferoptions.CreateTransferOptionsTypedDict
    )


class CreateTransferOptionsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The partner's Moov account ID."""

    create_transfer_options: Annotated[
        components_createtransferoptions.CreateTransferOptions,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateTransferOptionsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_transferoptions.TransferOptionsTypedDict


class CreateTransferOptionsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_transferoptions.TransferOptions



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    card as components_card,
    linkcard as components_linkcard,
    linkcardwaitfor as components_linkcardwaitfor,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class LinkCardRequestTypedDict(TypedDict):
    account_id: str
    link_card: components_linkcard.LinkCardTypedDict
    x_wait_for: NotRequired[components_linkcardwaitfor.LinkCardWaitFor]
    r"""Optional header to wait for certain events, such as the creation of a payment method, to occur before returning a response.

    When this header is set to `payment-method`, the response will include any payment methods that were created for the newly
    linked card in the `paymentMethods` field. Otherwise, the `paymentMethods` field will be omitted from the response.
    """


class LinkCardRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    link_card: Annotated[
        components_linkcard.LinkCard,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    x_wait_for: Annotated[
        Optional[components_linkcardwaitfor.LinkCardWaitFor],
        pydantic.Field(alias="x-wait-for"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Optional header to wait for certain events, such as the creation of a payment method, to occur before returning a response.

    When this header is set to `payment-method`, the response will include any payment methods that were created for the newly
    linked card in the `paymentMethods` field. Otherwise, the `paymentMethods` field will be omitted from the response.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["x-wait-for"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class LinkCardResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_card.CardTypedDict


class LinkCardResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_card.Card



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import adjustment as components_adjustment
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListAdjustmentsRequestTypedDict(TypedDict):
    account_id: str
    wallet_id: NotRequired[str]
    r"""A wallet ID to filter adjustments by."""


class ListAdjustmentsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    wallet_id: Annotated[
        Optional[str],
        pydantic.Field(alias="walletID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""A wallet ID to filter adjustments by."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["walletID"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class ListAdjustmentsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[components_adjustment.AdjustmentTypedDict]


class ListAdjustmentsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[components_adjustment.Adjustment]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    bankaccountverificationcreated as components_bankaccountverificationcreated,
    bankaccountwaitfor as components_bankaccountwaitfor,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class InitiateBankAccountVerificationRequestTypedDict(TypedDict):
    account_id: str
    bank_account_id: str
    x_wait_for: NotRequired[components_bankaccountwaitfor.BankAccountWaitFor]
    r"""Optional header to wait for certain events, such as the rail response, to occur before returning a response.

    When this header is set to `rail-response`, the endpoint will wait for a sent-credit or failed status from the payment rail.
    """


class InitiateBankAccountVerificationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    bank_account_id: Annotated[
        str,
        pydantic.Field(alias="bankAccountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    x_wait_for: Annotated[
        Optional[components_bankaccountwaitfor.BankAccountWaitFor],
        pydantic.Field(alias="x-wait-for"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Optional header to wait for certain events, such as the rail response, to occur before returning a response.

    When this header is set to `rail-response`, the endpoint will wait for a sent-credit or failed status from the payment rail.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["x-wait-for"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class InitiateBankAccountVerificationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_bankaccountverificationcreated.BankAccountVerificationCreatedTypedDict


class InitiateBankAccountVerificationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_bankaccountverificationcreated.BankAccountVerificationCreated



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createwallet as components_createwallet,
    wallet as components_wallet,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateWalletRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov account ID the wallet belongs to."""
    create_wallet: components_createwallet.CreateWalletTypedDict


class CreateWalletRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov account ID the wallet belongs to."""

    create_wallet: Annotated[
        components_createwallet.CreateWallet,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateWalletResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_wallet.WalletTypedDict


class CreateWalletResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_wallet.Wallet



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import paymentmethod as components_paymentmethod
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetPaymentMethodRequestTypedDict(TypedDict):
    account_id: str
    payment_method_id: str


class GetPaymentMethodRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    payment_method_id: Annotated[
        str,
        pydantic.Field(alias="paymentMethodID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetPaymentMethodResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_paymentmethod.PaymentMethodTypedDict


class GetPaymentMethodResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_paymentmethod.PaymentMethod



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetAvatarRequestTypedDict(TypedDict):
    unique_id: str
    r"""Any unique ID associated with an account such as accountID, representativeID, routing number, or userID."""


class GetAvatarRequest(BaseModel):
    unique_id: Annotated[
        str,
        pydantic.Field(alias="uniqueID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Any unique ID associated with an account such as accountID, representativeID, routing number, or userID."""


class GetAvatarResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: httpx.Response


class GetAvatarResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: httpx.Response



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    enrichedbusinessresponse as components_enrichedbusinessresponse,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, QueryParamMetadata
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetEnrichmentProfileRequestTypedDict(TypedDict):
    email: str


class GetEnrichmentProfileRequest(BaseModel):
    email: Annotated[
        str, FieldMetadata(query=QueryParamMetadata(style="form", explode=False))
    ]


class GetEnrichmentProfileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_enrichedbusinessresponse.EnrichedBusinessResponseTypedDict


class GetEnrichmentProfileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_enrichedbusinessresponse.EnrichedBusinessResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import incurredfee as components_incurredfee
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListFeeRevenueRequestTypedDict(TypedDict):
    account_id: str
    r"""The Partner's AccountID."""
    skip: NotRequired[int]
    count: NotRequired[int]
    transfer_id: NotRequired[str]
    r"""Optional transfer ID to filter the results by."""
    dispute_id: NotRequired[str]
    r"""Optional dispute ID to filter the results by."""
    residual_id: NotRequired[str]
    r"""Optional residual ID to filter the results by."""
    start_date_time: NotRequired[str]
    r"""Optional date-time to inclusively filter all fees created after this date-time."""
    end_date_time: NotRequired[str]
    r"""Optional date-time to exclusively filter all fees created before this date-time."""


class ListFeeRevenueRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Partner's AccountID."""

    skip: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    count: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    transfer_id: Annotated[
        Optional[str],
        pydantic.Field(alias="transferID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Optional transfer ID to filter the results by."""

    dispute_id: Annotated[
        Optional[str],
        pydantic.Field(alias="disputeID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Optional dispute ID to filter the results by."""

    residual_id: Annotated[
        Optional[str],
        pydantic.Field(alias="residualID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Optional residual ID to filter the results by."""

    start_date_time: Annotated[
        Optional[str],
        pydantic.Field(alias="startDateTime"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Optional date-time to inclusively filter all fees created after this date-time."""

    end_date_time: Annotated[
        Optional[str],
        pydantic.Field(alias="endDateTime"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Optional date-time to exclusively filter all fees created before this date-time."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "skip",
                "count",
                "transferID",
                "disputeID",
                "residualID",
                "startDateTime",
                "endDateTime",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class ListFeeRevenueResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: List[components_incurredfee.IncurredFeeTypedDict]


class ListFeeRevenueResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: List[components_incurredfee.IncurredFee]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    issuedcard as components_issuedcard,
    requestcard as components_requestcard,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class RequestCardRequestTypedDict(TypedDict):
    account_id: str
    r"""The Moov business account for which the card is to be issued."""
    request_card: components_requestcard.RequestCardTypedDict


class RequestCardRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The Moov business account for which the card is to be issued."""

    request_card: Annotated[
        components_requestcard.RequestCard,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class RequestCardResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_issuedcard.IssuedCardTypedDict


class RequestCardResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_issuedcard.IssuedCard



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    occurrencesresponse as components_occurrencesresponse,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetScheduledOccurrenceRequestTypedDict(TypedDict):
    account_id: str
    schedule_id: str
    occurrence_filter: str
    r"""Allows the specification of additional filters beyond the string.

    Specifying a string returns the exact occurrence.
    Specifying a RFC 3339 timestamp returns the latest occurrence at or before that timestamp.
    Specifying `latest` returns the latest occurrence at or before now.
    """


class GetScheduledOccurrenceRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    schedule_id: Annotated[
        str,
        pydantic.Field(alias="scheduleID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    occurrence_filter: Annotated[
        str,
        pydantic.Field(alias="occurrenceFilter"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Allows the specification of additional filters beyond the string.

    Specifying a string returns the exact occurrence.
    Specifying a RFC 3339 timestamp returns the latest occurrence at or before that timestamp.
    Specifying `latest` returns the latest occurrence at or before now.
    """


class GetScheduledOccurrenceResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_occurrencesresponse.OccurrencesResponseTypedDict


class GetScheduledOccurrenceResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_occurrencesresponse.OccurrencesResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from dataclasses import dataclass, field
import httpx
from moovio_sdk.models.errors import MoovError
from moovio_sdk.types import BaseModel
import pydantic
from typing import Dict, Optional
from typing_extensions import Annotated


class ConnectAccountRequestValidationErrorData(BaseModel):
    principal_account_id: Annotated[
        Optional[str], pydantic.Field(alias="principalAccountID")
    ] = None
    allow_scopes: Annotated[
        Optional[Dict[str, str]], pydantic.Field(alias="allowScopes")
    ] = None


@dataclass(unsafe_hash=True)
class ConnectAccountRequestValidationError(MoovError):
    data: ConnectAccountRequestValidationErrorData = field(hash=False)

    def __init__(
        self,
        data: ConnectAccountRequestValidationErrorData,
        raw_response: httpx.Response,
        body: Optional[str] = None,
    ):
        message = body or raw_response.text
        super().__init__(message, raw_response, body)
        object.__setattr__(self, "data", data)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    ticket as components_ticket,
    updateticket as components_updateticket,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateTicketRequestTypedDict(TypedDict):
    account_id: str
    ticket_id: str
    update_ticket: components_updateticket.UpdateTicketTypedDict


class UpdateTicketRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    ticket_id: Annotated[
        str,
        pydantic.Field(alias="ticketID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    update_ticket: Annotated[
        components_updateticket.UpdateTicket,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateTicketResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_ticket.TicketTypedDict


class UpdateTicketResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_ticket.Ticket



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    product as components_product,
    productrequest as components_productrequest,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateProductRequestTypedDict(TypedDict):
    account_id: str
    product_request: components_productrequest.ProductRequestTypedDict


class CreateProductRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    product_request: Annotated[
        components_productrequest.ProductRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateProductResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_product.ProductTypedDict


class CreateProductResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_product.Product



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CardAcceptanceMethodsTypedDict(TypedDict):
    r"""Describes the distribution of card transactions by payment method."""

    in_person_percentage: NotRequired[int]
    r"""Percentage of card transactions that are in-person payments. Minimum value is 0, maximum is 100."""
    mail_or_phone_percentage: NotRequired[int]
    r"""Percentage of card transactions that are mail or phone payments. Minimum value is 0, maximum is 100."""
    online_percentage: NotRequired[int]
    r"""Percentage of card transactions that are online payments. Minimum value is 0, maximum is 100."""


class CardAcceptanceMethods(BaseModel):
    r"""Describes the distribution of card transactions by payment method."""

    in_person_percentage: Annotated[
        Optional[int], pydantic.Field(alias="inPersonPercentage")
    ] = None
    r"""Percentage of card transactions that are in-person payments. Minimum value is 0, maximum is 100."""

    mail_or_phone_percentage: Annotated[
        Optional[int], pydantic.Field(alias="mailOrPhonePercentage")
    ] = None
    r"""Percentage of card transactions that are mail or phone payments. Minimum value is 0, maximum is 100."""

    online_percentage: Annotated[
        Optional[int], pydantic.Field(alias="onlinePercentage")
    ] = None
    r"""Percentage of card transactions that are online payments. Minimum value is 0, maximum is 100."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["inPersonPercentage", "mailOrPhonePercentage", "onlinePercentage"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CardAcceptanceMethods.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    bankaccountverification as components_bankaccountverification,
    completebankaccountverification as components_completebankaccountverification,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CompleteBankAccountVerificationRequestTypedDict(TypedDict):
    account_id: str
    bank_account_id: str
    complete_bank_account_verification: components_completebankaccountverification.CompleteBankAccountVerificationTypedDict


class CompleteBankAccountVerificationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    bank_account_id: Annotated[
        str,
        pydantic.Field(alias="bankAccountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    complete_bank_account_verification: Annotated[
        components_completebankaccountverification.CompleteBankAccountVerification,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CompleteBankAccountVerificationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_bankaccountverification.BankAccountVerificationTypedDict


class CompleteBankAccountVerificationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_bankaccountverification.BankAccountVerification



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    termsofservicetoken as components_termsofservicetoken,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata, HeaderMetadata
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetTermsOfServiceTokenRequestTypedDict(TypedDict):
    origin: NotRequired[str]
    r"""Indicates the domain from which the request originated. Required if referer header is not present."""
    referer: NotRequired[str]
    r"""Specifies the URL of the resource from which the request originated. Required if origin header is not present."""


class GetTermsOfServiceTokenRequest(BaseModel):
    origin: Annotated[
        Optional[str],
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Indicates the domain from which the request originated. Required if referer header is not present."""

    referer: Annotated[
        Optional[str],
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""Specifies the URL of the resource from which the request originated. Required if origin header is not present."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["origin", "referer"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class GetTermsOfServiceTokenResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_termsofservicetoken.TermsOfServiceTokenTypedDict


class GetTermsOfServiceTokenResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_termsofservicetoken.TermsOfServiceToken



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from moovio_sdk import utils
from moovio_sdk._hooks import HookContext
from moovio_sdk.models import components, errors, operations
from moovio_sdk.types import OptionalNullable, UNSET
from moovio_sdk.utils import get_security_from_env
from moovio_sdk.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union


class ResolutionLinks(BaseSDK):
    def create(
        self,
        *,
        account_id: str,
        recipient: Union[
            components.ResolutionLinkRecipient,
            components.ResolutionLinkRecipientTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateResolutionLinkResponse:
        r"""Create a resolution link for the specified account. Resolution links are temporary, secure links
        sent to merchants to resolve account requirements such as KYC verification or document uploads.  Only one active resolution link
        is allowed per connected account.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.write`, `/accounts/{accountID}/representatives.write` and `/accounts/{accountID}/files.write` scopes.

        :param account_id:
        :param recipient: The recipient contact information for the resolution link.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.CreateResolutionLinkRequest(
            account_id=account_id,
            create_resolution_link=components.CreateResolutionLink(
                recipient=utils.get_pydantic_model(
                    recipient, components.ResolutionLinkRecipient
                ),
            ),
        )

        req = self._build_request(
            method="POST",
            path="/accounts/{accountID}/resolution-links",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.create_resolution_link,
                False,
                False,
                "json",
                components.CreateResolutionLink,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "422",
                "429",
                "4XX",
                "500",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateResolutionLinkResponse(
                result=unmarshal_json_response(components.ResolutionLink, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["400", "409"], "application/json"):
            response_data = unmarshal_json_response(errors.GenericErrorData, http_res)
            raise errors.GenericError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.CreateResolutionLinkErrorData, http_res
            )
            raise errors.CreateResolutionLinkError(response_data, http_res)
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def create_async(
        self,
        *,
        account_id: str,
        recipient: Union[
            components.ResolutionLinkRecipient,
            components.ResolutionLinkRecipientTypedDict,
        ],
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.CreateResolutionLinkResponse:
        r"""Create a resolution link for the specified account. Resolution links are temporary, secure links
        sent to merchants to resolve account requirements such as KYC verification or document uploads.  Only one active resolution link
        is allowed per connected account.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.write`, `/accounts/{accountID}/representatives.write` and `/accounts/{accountID}/files.write` scopes.

        :param account_id:
        :param recipient: The recipient contact information for the resolution link.
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.CreateResolutionLinkRequest(
            account_id=account_id,
            create_resolution_link=components.CreateResolutionLink(
                recipient=utils.get_pydantic_model(
                    recipient, components.ResolutionLinkRecipient
                ),
            ),
        )

        req = self._build_request_async(
            method="POST",
            path="/accounts/{accountID}/resolution-links",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request.create_resolution_link,
                False,
                False,
                "json",
                components.CreateResolutionLink,
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="createResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "422",
                "429",
                "4XX",
                "500",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return operations.CreateResolutionLinkResponse(
                result=unmarshal_json_response(components.ResolutionLink, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["400", "409"], "application/json"):
            response_data = unmarshal_json_response(errors.GenericErrorData, http_res)
            raise errors.GenericError(response_data, http_res)
        if utils.match_response(http_res, "422", "application/json"):
            response_data = unmarshal_json_response(
                errors.CreateResolutionLinkErrorData, http_res
            )
            raise errors.CreateResolutionLinkError(response_data, http_res)
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def list(
        self,
        *,
        account_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.ListResolutionLinksResponse:
        r"""List resolution links for the specified account.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.read` scope.

        :param account_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.ListResolutionLinksRequest(
            account_id=account_id,
        )

        req = self._build_request(
            method="GET",
            path="/accounts/{accountID}/resolution-links",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listResolutionLinks",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "429", "4XX", "500", "504", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.ListResolutionLinksResponse(
                result=unmarshal_json_response(
                    List[components.ResolutionLink], http_res
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["401", "403", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def list_async(
        self,
        *,
        account_id: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.ListResolutionLinksResponse:
        r"""List resolution links for the specified account.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.read` scope.

        :param account_id:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.ListResolutionLinksRequest(
            account_id=account_id,
        )

        req = self._build_request_async(
            method="GET",
            path="/accounts/{accountID}/resolution-links",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="listResolutionLinks",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "429", "4XX", "500", "504", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.ListResolutionLinksResponse(
                result=unmarshal_json_response(
                    List[components.ResolutionLink], http_res
                ),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["401", "403", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def get(
        self,
        *,
        account_id: str,
        resolution_link_code: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.GetResolutionLinkResponse:
        r"""Get a resolution link by code.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.read` scope.

        :param account_id:
        :param resolution_link_code:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.GetResolutionLinkRequest(
            account_id=account_id,
            resolution_link_code=resolution_link_code,
        )

        req = self._build_request(
            method="GET",
            path="/accounts/{accountID}/resolution-links/{resolutionLinkCode}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "404", "429", "4XX", "500", "504", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.GetResolutionLinkResponse(
                result=unmarshal_json_response(components.ResolutionLink, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def get_async(
        self,
        *,
        account_id: str,
        resolution_link_code: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.GetResolutionLinkResponse:
        r"""Get a resolution link by code.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.read` scope.

        :param account_id:
        :param resolution_link_code:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.GetResolutionLinkRequest(
            account_id=account_id,
            resolution_link_code=resolution_link_code,
        )

        req = self._build_request_async(
            method="GET",
            path="/accounts/{accountID}/resolution-links/{resolutionLinkCode}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="getResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=["401", "403", "404", "429", "4XX", "500", "504", "5XX"],
            retry_config=retry_config,
        )

        if utils.match_response(http_res, "200", "application/json"):
            return operations.GetResolutionLinkResponse(
                result=unmarshal_json_response(components.ResolutionLink, http_res),
                headers=utils.get_response_headers(http_res.headers),
            )
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    def disable(
        self,
        *,
        account_id: str,
        resolution_link_code: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.DisableResolutionLinkResponse:
        r"""Disable a resolution link. Disabled resolution links can no longer be used by merchants.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.write` scope.

        :param account_id:
        :param resolution_link_code:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.DisableResolutionLinkRequest(
            account_id=account_id,
            resolution_link_code=resolution_link_code,
        )

        req = self._build_request(
            method="DELETE",
            path="/accounts/{accountID}/resolution-links/{resolutionLinkCode}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="disableResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "429",
                "4XX",
                "500",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return operations.DisableResolutionLinkResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(http_res, ["400", "409"], "application/json"):
            response_data = unmarshal_json_response(errors.GenericErrorData, http_res)
            raise errors.GenericError(response_data, http_res)
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)

    async def disable_async(
        self,
        *,
        account_id: str,
        resolution_link_code: str,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> operations.DisableResolutionLinkResponse:
        r"""Disable a resolution link. Disabled resolution links can no longer be used by merchants.

        To access this endpoint using an [access token](https://docs.moov.io/api/authentication/access-tokens/)
        you'll need to specify the `/accounts/{accountID}/profile.write` scope.

        :param account_id:
        :param resolution_link_code:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = operations.DisableResolutionLinkRequest(
            account_id=account_id,
            resolution_link_code=resolution_link_code,
        )

        req = self._build_request_async(
            method="DELETE",
            path="/accounts/{accountID}/resolution-links/{resolutionLinkCode}",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=False,
            request_has_path_params=True,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="disableResolutionLink",
                oauth2_scopes=None,
                security_source=get_security_from_env(
                    self.sdk_configuration.security, components.Security
                ),
            ),
            request=req,
            error_status_codes=[
                "400",
                "401",
                "403",
                "404",
                "409",
                "429",
                "4XX",
                "500",
                "504",
                "5XX",
            ],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "204", "*"):
            return operations.DisableResolutionLinkResponse(
                headers=utils.get_response_headers(http_res.headers)
            )
        if utils.match_response(http_res, ["400", "409"], "application/json"):
            response_data = unmarshal_json_response(errors.GenericErrorData, http_res)
            raise errors.GenericError(response_data, http_res)
        if utils.match_response(http_res, ["401", "403", "404", "429"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, ["500", "504"], "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.APIError("API error occurred", http_res, http_res_text)

        raise errors.APIError("Unexpected response received", http_res)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    terminalapplicationversion as components_terminalapplicationversion,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class CreateTerminalApplicationVersionRequestTypedDict(TypedDict):
    terminal_application_id: str
    terminal_application_version: (
        components_terminalapplicationversion.TerminalApplicationVersionTypedDict
    )


class CreateTerminalApplicationVersionRequest(BaseModel):
    terminal_application_id: Annotated[
        str,
        pydantic.Field(alias="terminalApplicationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    terminal_application_version: Annotated[
        components_terminalapplicationversion.TerminalApplicationVersion,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class CreateTerminalApplicationVersionResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_terminalapplicationversion.TerminalApplicationVersionTypedDict


class CreateTerminalApplicationVersionResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_terminalapplicationversion.TerminalApplicationVersion



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    updateapplepaymerchantdomains as components_updateapplepaymerchantdomains,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateApplePayMerchantDomainsRequestTypedDict(TypedDict):
    account_id: str
    r"""ID of the Moov account representing the merchant."""
    update_apple_pay_merchant_domains: (
        components_updateapplepaymerchantdomains.UpdateApplePayMerchantDomainsTypedDict
    )


class UpdateApplePayMerchantDomainsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""ID of the Moov account representing the merchant."""

    update_apple_pay_merchant_domains: Annotated[
        components_updateapplepaymerchantdomains.UpdateApplePayMerchantDomains,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateApplePayMerchantDomainsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]


class UpdateApplePayMerchantDomainsResponse(BaseModel):
    headers: Dict[str, List[str]]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    createevidencefilemultipart as components_createevidencefilemultipart,
    evidenceuploadresponse as components_evidenceuploadresponse,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UploadDisputeEvidenceFileRequestTypedDict(TypedDict):
    account_id: str
    dispute_id: str
    create_evidence_file_multi_part: (
        components_createevidencefilemultipart.CreateEvidenceFileMultiPartTypedDict
    )


class UploadDisputeEvidenceFileRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    dispute_id: Annotated[
        str,
        pydantic.Field(alias="disputeID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    create_evidence_file_multi_part: Annotated[
        components_createevidencefilemultipart.CreateEvidenceFileMultiPart,
        FieldMetadata(request=RequestMetadata(media_type="multipart/form-data")),
    ]


class UploadDisputeEvidenceFileResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_evidenceuploadresponse.EvidenceUploadResponseTypedDict


class UploadDisputeEvidenceFileResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_evidenceuploadresponse.EvidenceUploadResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    itemlistnextpage as components_itemlistnextpage,
    ticket as components_ticket,
    ticketstatus as components_ticketstatus,
)
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListTicketsRequestTypedDict(TypedDict):
    account_id: str
    cursor: NotRequired[str]
    count: NotRequired[int]
    status: NotRequired[components_ticketstatus.TicketStatus]
    foreign_id: NotRequired[str]


class ListTicketsRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    cursor: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    count: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    status: Annotated[
        Optional[components_ticketstatus.TicketStatus],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    foreign_id: Annotated[
        Optional[str],
        pydantic.Field(alias="foreignID"),
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["cursor", "count", "status", "foreignID"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class ListTicketsResponseBodyTypedDict(TypedDict):
    r"""A paginated list of items. The `nextPage` field is omitted if there are no more pages available."""

    items: List[components_ticket.TicketTypedDict]
    next_page: NotRequired[components_itemlistnextpage.ItemListNextPageTypedDict]


class ListTicketsResponseBody(BaseModel):
    r"""A paginated list of items. The `nextPage` field is omitted if there are no more pages available."""

    items: List[components_ticket.Ticket]

    next_page: Annotated[
        Optional[components_itemlistnextpage.ItemListNextPage],
        pydantic.Field(alias="nextPage"),
    ] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["nextPage"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


class ListTicketsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ListTicketsResponseBodyTypedDict


class ListTicketsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ListTicketsResponseBody


try:
    ListTicketsResponseBody.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    underwriting as components_underwriting,
    upsertunderwriting as components_upsertunderwriting,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class SaveUnderwritingRequestTypedDict(TypedDict):
    account_id: str
    upsert_underwriting: components_upsertunderwriting.UpsertUnderwritingTypedDict


class SaveUnderwritingRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    upsert_underwriting: Annotated[
        components_upsertunderwriting.UpsertUnderwriting,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class SaveUnderwritingResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_underwriting.UnderwritingTypedDict


class SaveUnderwritingResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_underwriting.Underwriting



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import httpx
from moovio_sdk.models.components import statement as components_statement
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List, Union
from typing_extensions import Annotated, TypeAliasType, TypedDict


class GetStatementRequestTypedDict(TypedDict):
    account_id: str
    statement_id: str


class GetStatementRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    statement_id: Annotated[
        str,
        pydantic.Field(alias="statementID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


GetStatementResponseResultTypedDict = TypeAliasType(
    "GetStatementResponseResultTypedDict",
    Union[components_statement.StatementTypedDict, httpx.Response],
)


GetStatementResponseResult = TypeAliasType(
    "GetStatementResponseResult", Union[components_statement.Statement, httpx.Response]
)


class GetStatementResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: GetStatementResponseResultTypedDict


class GetStatementResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: GetStatementResponseResult



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import sweepconfig as components_sweepconfig
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetSweepConfigRequestTypedDict(TypedDict):
    account_id: str
    sweep_config_id: str


class GetSweepConfigRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    sweep_config_id: Annotated[
        str,
        pydantic.Field(alias="sweepConfigID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetSweepConfigResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_sweepconfig.SweepConfigTypedDict


class GetSweepConfigResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_sweepconfig.SweepConfig



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import webhooksecret as components_webhooksecret
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetWebhookSecretRequestTypedDict(TypedDict):
    webhook_id: str


class GetWebhookSecretRequest(BaseModel):
    webhook_id: Annotated[
        str,
        pydantic.Field(alias="webhookID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]


class GetWebhookSecretResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_webhooksecret.WebhookSecretTypedDict


class GetWebhookSecretResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_webhooksecret.WebhookSecret



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .transferpaymentmethodsbankaccount import (
    TransferPaymentMethodsBankAccount,
    TransferPaymentMethodsBankAccountTypedDict,
)
from enum import Enum
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class InstantBankCreditTransferPaymentMethodPaymentMethodType(str, Enum):
    INSTANT_BANK_CREDIT = "instant-bank-credit"


class InstantBankCreditTransferPaymentMethodTypedDict(TypedDict):
    r"""Instantly send funds to a bank account."""

    payment_method_id: str
    r"""ID of the payment method."""
    payment_method_type: InstantBankCreditTransferPaymentMethodPaymentMethodType
    bank_account: TransferPaymentMethodsBankAccountTypedDict
    r"""A bank account as contained within a payment method."""


class InstantBankCreditTransferPaymentMethod(BaseModel):
    r"""Instantly send funds to a bank account."""

    payment_method_id: Annotated[str, pydantic.Field(alias="paymentMethodID")]
    r"""ID of the payment method."""

    payment_method_type: Annotated[
        InstantBankCreditTransferPaymentMethodPaymentMethodType,
        pydantic.Field(alias="paymentMethodType"),
    ]

    bank_account: Annotated[
        TransferPaymentMethodsBankAccount, pydantic.Field(alias="bankAccount")
    ]
    r"""A bank account as contained within a payment method."""


try:
    InstantBankCreditTransferPaymentMethod.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import cancellation as components_cancellation
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class GetCancellationRequestTypedDict(TypedDict):
    account_id: str
    r"""Moov account ID of the partner or transfer's source or destination."""
    transfer_id: str
    r"""Identifier for the transfer."""
    cancellation_id: str
    r"""Identifier for the cancellation."""


class GetCancellationRequest(BaseModel):
    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Moov account ID of the partner or transfer's source or destination."""

    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the transfer."""

    cancellation_id: Annotated[
        str,
        pydantic.Field(alias="cancellationID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the cancellation."""


class GetCancellationResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_cancellation.CancellationTypedDict


class GetCancellationResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_cancellation.Cancellation



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ResolutionLinkTypedDict(TypedDict):
    r"""A temporary, secure link sent to a merchant to resolve account requirements such as KYC verification or document uploads."""

    code: str
    r"""A unique nanoid identifier for the resolution link."""
    account_id: str
    r"""The ID of the merchant account this resolution link is associated with."""
    partner_account_id: str
    r"""The ID of the partner account this resolution link is associated with."""
    recipient: str
    r"""The recipient contact information for the resolution link."""
    url: str
    r"""The URL of the resolution link."""
    created_on: datetime
    r"""The date and time the resolution link was created."""
    updated_on: datetime
    r"""The date and time the resolution link was last updated."""
    expires_on: datetime
    r"""The date and time the resolution link expires."""
    disabled_on: NotRequired[datetime]
    r"""The date and time the resolution link was disabled, if applicable."""


class ResolutionLink(BaseModel):
    r"""A temporary, secure link sent to a merchant to resolve account requirements such as KYC verification or document uploads."""

    code: str
    r"""A unique nanoid identifier for the resolution link."""

    account_id: Annotated[str, pydantic.Field(alias="accountID")]
    r"""The ID of the merchant account this resolution link is associated with."""

    partner_account_id: Annotated[str, pydantic.Field(alias="partnerAccountID")]
    r"""The ID of the partner account this resolution link is associated with."""

    recipient: str
    r"""The recipient contact information for the resolution link."""

    url: str
    r"""The URL of the resolution link."""

    created_on: Annotated[datetime, pydantic.Field(alias="createdOn")]
    r"""The date and time the resolution link was created."""

    updated_on: Annotated[datetime, pydantic.Field(alias="updatedOn")]
    r"""The date and time the resolution link was last updated."""

    expires_on: Annotated[datetime, pydantic.Field(alias="expiresOn")]
    r"""The date and time the resolution link expires."""

    disabled_on: Annotated[Optional[datetime], pydantic.Field(alias="disabledOn")] = (
        None
    )
    r"""The date and time the resolution link was disabled, if applicable."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["disabledOn"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ResolutionLink.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.models.components import (
    patchtransfer as components_patchtransfer,
    transfer as components_transfer,
)
from moovio_sdk.types import BaseModel
from moovio_sdk.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import Dict, List
from typing_extensions import Annotated, TypedDict


class UpdateTransferRequestTypedDict(TypedDict):
    transfer_id: str
    r"""Identifier for the transfer."""
    account_id: str
    patch_transfer: components_patchtransfer.PatchTransferTypedDict


class UpdateTransferRequest(BaseModel):
    transfer_id: Annotated[
        str,
        pydantic.Field(alias="transferID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Identifier for the transfer."""

    account_id: Annotated[
        str,
        pydantic.Field(alias="accountID"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]

    patch_transfer: Annotated[
        components_patchtransfer.PatchTransfer,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateTransferResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: components_transfer.TransferTypedDict


class UpdateTransferResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: components_transfer.Transfer



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .patchbusiness import PatchBusiness, PatchBusinessTypedDict
from .patchindividual import PatchIndividual, PatchIndividualTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PatchProfileTypedDict(TypedDict):
    r"""Describes the fields available when patching a profile.
    Each object can be patched independent of patching the other fields.
    """

    individual: NotRequired[PatchIndividualTypedDict]
    r"""Describes the fields available when patching an individual."""
    business: NotRequired[PatchBusinessTypedDict]


class PatchProfile(BaseModel):
    r"""Describes the fields available when patching a profile.
    Each object can be patched independent of patching the other fields.
    """

    individual: Optional[PatchIndividual] = None
    r"""Describes the fields available when patching an individual."""

    business: Optional[PatchBusiness] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["individual", "business"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
